@@ -22,7 +22,7 @@ pub fn format() -> Formatter {
 
 /// A test format that trivially encodes the primitives as their
 /// little endian, in memory byte representations.
-#[derive(Debug)]
+#[derive(Copy, Clone, Debug)]
 pub struct Formatter;
 
 impl diny::backend::Format for Formatter {
