@@ -9,5 +9,5 @@ use common::method::eq::*;
 #[test]
 fn can_serialize_arc() {
     const LEN: usize = 8;
-    test_serialize_exact::<Arc<u64>, LEN>(&Arc::new(u64::MIN));
+    test_serialize_exact::<Arc<u64>, LEN>(Arc::new(u64::MIN));
 }
\ No newline at end of file
