@@ -13,14 +13,14 @@ mod test {
     
     #[test]
     fn can_serialize_empty_btree_set() {
-        test_serialize_exact::<BTreeSet<u64>, {SEQ_LEN}>(&BTreeSet::new());
+        test_serialize_exact::<BTreeSet<u64>, {SEQ_LEN}>(BTreeSet::new());
     }
     
     #[test]
     fn can_serialize_btree_set_single() {
         let mut vd = BTreeSet::new();
         vd.insert(5);
-        test_serialize_exact::<BTreeSet<u64>, {SEQ_LEN + 8}>(&vd);
+        test_serialize_exact::<BTreeSet<u64>, {SEQ_LEN + 8}>(vd);
     }
     
     #[test]
@@ -29,6 +29,6 @@ mod test {
         vd.insert(1);
         vd.insert(2);
         vd.insert(3);
-        test_serialize_exact::<BTreeSet<u64>, {SEQ_LEN+8*3}>(&vd);
+        test_serialize_exact::<BTreeSet<u64>, {SEQ_LEN+8*3}>(vd);
     }
 }
