@@ -8,5 +8,5 @@ use common::method::eq::*;
 #[test]
 fn can_serialize_phantom_data() {
     const LEN: usize = 0;
-    test_serialize_exact::<PhantomData<u64>, LEN>(&PhantomData);
+    test_serialize_exact::<PhantomData<u64>, LEN>(PhantomData);
 }
\ No newline at end of file
